#ifndef __FUELMFD_H
#define __FUELMFD_H

#define MFDversion "031129"

const int MAX_FUEL_TANKS = 99;

// fuel modes
typedef enum {
	PM_CROSSFEED, PM_LOAD, PM_UNLOAD, PM_VENT
} PUMPMODE;

// pump rates
typedef enum {
	PR_OFF, PR_LOW, PR_MEDIUM, PR_HIGH
} PUMPRATE;

// fuel tank
typedef struct {
	VESSEL *vessel;	// vessel tank is in
	int propnum;	// which propellant tank it is
} FUEL_TANK;

typedef struct {
	FUEL_TANK TargetTank;	// tank in target vessel
	FUEL_TANK SourceTank;	// tank in source vessel
	UINT DockPort;			// dock port on target vessel
	PUMPMODE PumpMode;		// pump mode
	PUMPRATE PumpRate;		// pump rate
} FUEL_TRANSFER;

class FuelMFD: public MFD {
public:
	int HelpPage;

	FuelMFD (DWORD w, DWORD h, VESSEL *vessel);
	~FuelMFD ();
	void Update (HDC hDC);
	static int MsgProc (UINT msg, UINT mfd, WPARAM wparam, LPARAM lparam);
	bool ConsumeKeyBuffered (DWORD key);
	bool ConsumeButton (int bt, int event);
	char *ButtonLabel (int bt);
	int  ButtonMenu (const MFDBUTTONMENU **menu) const;
	void WriteStatus (FILEHANDLE scn) const;
	void ReadStatus (FILEHANDLE scn);
	void RecallStatus(void);
	void StoreStatus(void) const;
	void SetTransferSource(void);
	void ShowHelp(const HDC hDC);
	void ShowFuelInfo(const HDC hDC);
	void ShowFuelGauge(const HDC hDC, const int x, const int y, const FUEL_TANK &ft);
	void ShowSourceTank(const HDC hDC);
	void ShowTargetTank(const HDC hDC);
	void ShowDockingPort(const HDC hDC);
};

#endif //!__FUELMFD_H
